@@ -20,22 +20,22 @@
 """Init the Glances software."""
 
 __appname__ = 'glances'
-__version__ = '2.1.1'
+__version__ = '2.2'
 __author__ = 'Nicolas Hennion <nicolas@nicolargo.com>'
 __license__ = 'LGPL'
 
 # Import system lib
 import gettext
 import locale
+import platform
 import signal
 import sys
-import platform
 
 # Import psutil
 try:
     from psutil import __version__ as __psutil_version
 except ImportError:
-    print('psutil library not found. Glances cannot start.')
+    print('PSutil library not found. Glances cannot start.')
     sys.exit(1)
 
 # Import Glances libs
@@ -50,11 +50,11 @@ psutil_version = tuple([int(num) for num in __psutil_version.split('.')])
 # First log with Glances and PSUtil version
 logger.info('Start Glances {0}'.format(__version__))
 logger.info('{0} {1} and PSutil {2} detected'.format(platform.python_implementation(),
-                                                 platform.python_version(), 
-                                                 __psutil_version))
+                                                     platform.python_version(),
+                                                     __psutil_version))
 
 # Check PSutil version
-if psutil_version < psutil_min_version:    
+if psutil_version < psutil_min_version:
     logger.critical('PSutil 2.0 or higher is needed. Glances cannot start.')
     sys.exit(1)
 
@@ -121,25 +121,36 @@ def main():
         standalone.serve_forever()
 
     elif core.is_client():
-        logger.info("Start client mode")
+        if core.is_client_browser():
+            logger.info("Start client mode (browser)")
 
-        # Import the Glances client module
-        from glances.core.glances_client import GlancesClient
+            # Import the Glances client browser module
+            from glances.core.glances_client_browser import GlancesClientBrowser
 
-        # Init the client
-        client = GlancesClient(config=core.get_config(),
-                               args=core.get_args())
+            # Init the client
+            client = GlancesClientBrowser(config=core.get_config(),
+                                          args=core.get_args())
 
-        # Test if client and server are in the same major version
-        if not client.login():
-            logger.critical(_("The server version is not compatible with the client"))
-            sys.exit(2)
+        else:
+            logger.info("Start client mode")
+
+            # Import the Glances client module
+            from glances.core.glances_client import GlancesClient
+
+            # Init the client
+            client = GlancesClient(config=core.get_config(),
+                                   args=core.get_args())
+
+            # Test if client and server are in the same major version
+            if not client.login():
+                logger.critical("The server version is not compatible with the client")
+                sys.exit(2)
 
         # Start the client loop
         client.serve_forever()
 
         # Shutdown the client
-        client.close()
+        client.end()
 
     elif core.is_server():
         logger.info("Start server mode")
